@@ -475,8 +475,8 @@ classdef CompactClassificationGAM
       if (isempty (XC))
         error ("CompactClassificationGAM.predict: XC is empty.");
       elseif (this.NumPredictors != columns (XC))
-        error (strcat (["CompactClassificationGAM.predict: XC must have"], ...
-                       [" the same number of features as the trained model."]));
+        error (strcat ("CompactClassificationGAM.predict: XC must have", ...
+                       " the same number of features as the trained model."));
       endif
 
       ## Clean XC data
@@ -494,19 +494,19 @@ classdef CompactClassificationGAM
           case "includeinteractions"
             tmpInt = varargin{2};
             if (! islogical (tmpInt) || (tmpInt != 0 && tmpInt != 1))
-              error (strcat (["CompactClassificationGAM.predict:"], ...
-                     [" includeinteractions must be a logical value."]));
+              error (strcat ("CompactClassificationGAM.predict:", ...
+                     " includeinteractions must be a logical value."));
             endif
             ## Check model for interactions
             if (tmpInt && isempty (this.IntMatrix))
-              error (strcat (["CompactClassificationGAM.predict: trained"], ...
-                             [" model does not include any interactions."]));
+              error (strcat ("CompactClassificationGAM.predict: trained", ...
+                             " model does not include any interactions."));
             endif
             incInt = tmpInt;
 
           otherwise
-            error (strcat (["CompactClassificationGAM.predict: invalid"], ...
-                           [" NAME in optional pairs of arguments."]));
+            error (strcat ("CompactClassificationGAM.predict: invalid", ...
+                           " NAME in optional pairs of arguments."));
         endswitch
         varargin (1:2) = [];
       endwhile
@@ -742,13 +742,13 @@ endfunction
 %! y = [1; 0; 1; 0; 1];
 %! Mdl = fitcgam (x, y, "interactions", "all");
 %! CMdl = compact (Mdl);
-%! l = {'0'; '0'; '0'; '0'; '0'};
+%! l = {'1'; '1'; '1'; '1'; '1'};
 %! s = [0.3760, 0.6240; 0.4259, 0.5741; 0.3760, 0.6240; ...
 %!      0.4259, 0.5741; 0.3760, 0.6240];
 %! [labels, scores] = predict (CMdl, x);
 %! assert (class (CMdl), "CompactClassificationGAM");
 %! assert ({CMdl.NumPredictors, CMdl.ResponseName}, {2, "Y"})
-%! assert (CMdl.ClassNames, {'1'; '0'})
+%! assert (CMdl.ClassNames, {'0'; '1'})
 %! assert (CMdl.PredictorNames, {'x1', 'x2'})
 %! assert (CMdl.ModelwInt.Intercept, 0.4055, 1e-1)
 %! assert (labels, l)
