@@ -134,9 +134,9 @@ function [paramhat, paramci] = nbinfit (x, alpha, varargin)
     if (! isstruct (options) || ! isfield (options, "Display") ||
         ! isfield (options, "MaxFunEvals") || ! isfield (options, "MaxIter")
                                            || ! isfield (options, "TolX"))
-      error (strcat (["nbinfit: 'options' argument must be a"], ...
-                     [" structure with 'Display', 'MaxFunEvals',"], ...
-                     [" 'MaxIter', and 'TolX' fields present."]));
+      error (strcat ("nbinfit: 'options' argument must be a", ...
+                     " structure with 'Display', 'MaxFunEvals',", ...
+                     " 'MaxIter', and 'TolX' fields present."));
     endif
   endif
 
@@ -170,8 +170,8 @@ function [paramhat, paramci] = nbinfit (x, alpha, varargin)
   ## Handle errors
   if (err == 0)
     if (output.funcCount >= options.MaxFunEvals)
-      warning (strcat (["nbinfit: maximum number of function"], ...
-                       [" evaluations are exceeded."]));
+      warning (strcat ("nbinfit: maximum number of function", ...
+                       " evaluations are exceeded."));
     elseif (output.iterations >= options.MaxIter)
       warning ("nbinfit: maximum number of iterations are exceeded.");
     endif
@@ -213,7 +213,7 @@ function nll = nbinfit_search (r, x, nx, sx, tol)
 endfunction
 
 %!demo
-%! ## Sample 2 populations from different negative binomial distibutions
+%! ## Sample 2 populations from different negative binomial distributions
 %! randp ("seed", 5); randg ("seed", 5);    # for reproducibility
 %! r1 = nbinrnd (2, 0.15, 5000, 1);
 %! randp ("seed", 8); randg ("seed", 8);    # for reproducibility
@@ -246,7 +246,7 @@ endfunction
 %!                  r_psA(1), r_psA(2)), ...
 %!          sprintf("PDF for sample 2 with estimated r=%0.2f and ps=%0.2f", ...
 %!                  r_psB(1), r_psB(2))})
-%! title ("Two population samples from negative different binomial distibutions")
+%! title ("Two population samples from negative different binomial distributions")
 %! hold off
 
 ## Test output
