@@ -70,15 +70,18 @@ function r = laplacernd (mu, beta, varargin)
   if (nargin == 2)
     sz = size (mu);
   elseif (nargin == 3)
-    if (isscalar (varargin{1}) && varargin{1} >= 0 ...
+    if (isscalar (varargin{1}) && varargin{1} >= 0
                                && varargin{1} == fix (varargin{1}))
       sz = [varargin{1}, varargin{1}];
-    elseif (isrow (varargin{1}) && all (varargin{1} >= 0) ...
+    elseif (isrow (varargin{1}) && all (varargin{1} >= 0)
                                 && all (varargin{1} == fix (varargin{1})))
       sz = varargin{1};
-    elseif
-      error (strcat (["laplacernd: SZ must be a scalar or a row vector"], ...
-                     [" of non-negative integers."]));
+    elseif (isempty (varargin{1}))
+      r = [];
+      return;
+    else
+      error (strcat ("laplacernd: SZ must be a scalar or a row vector", ...
+                     " of non-negative integers."));
     endif
   elseif (nargin > 3)
     posint = cellfun (@(x) (! isscalar (x) || x < 0 || x != fix (x)), varargin);
@@ -89,7 +92,8 @@ function r = laplacernd (mu, beta, varargin)
   endif
 
   ## Check that parameters match requested dimensions in size
-  if (! isscalar (mu) && ! isequal (size (mu), sz))
+  ## Use 'size (ones (sz))' to ignore any trailing singleton dimensions in SZ
+  if (! isscalar (mu) && ! isequal (size (mu), size (ones (sz))))
     error ("laplacernd: MU and BETA must be scalars or of size SZ.");
   endif
 
@@ -112,11 +116,11 @@ function r = laplacernd (mu, beta, varargin)
 endfunction
 
 ## Test output
-%!assert (size (laplacernd (1, 1)), [1 1])
-%!assert (size (laplacernd (1, ones (2,1))), [2, 1])
-%!assert (size (laplacernd (1, ones (2,2))), [2, 2])
-%!assert (size (laplacernd (ones (2,1), 1)), [2, 1])
-%!assert (size (laplacernd (ones (2,2), 1)), [2, 2])
+%!assert (size (laplacernd (1, 1)), [1, 1])
+%!assert (size (laplacernd (1, ones (2, 1))), [2, 1])
+%!assert (size (laplacernd (1, ones (2, 2))), [2, 2])
+%!assert (size (laplacernd (ones (2, 1), 1)), [2, 1])
+%!assert (size (laplacernd (ones (2, 2), 1)), [2, 2])
 %!assert (size (laplacernd (1, 1, 3)), [3, 3])
 %!assert (size (laplacernd (1, 1, [4, 1])), [4, 1])
 %!assert (size (laplacernd (1, 1, 4, 1)), [4, 1])
@@ -124,6 +128,8 @@ endfunction
 %!assert (size (laplacernd (1, 1, 0, 1)), [0, 1])
 %!assert (size (laplacernd (1, 1, 1, 0)), [1, 0])
 %!assert (size (laplacernd (1, 1, 1, 2, 0, 5)), [1, 2, 0, 5])
+%!assert (size (laplacernd (1, 1, [])), [0, 0])
+%!assert (size (laplacernd (1, 1, [2, 0, 2, 1])), [2, 0, 2])
 
 ## Test class of input preserved
 %!assert (class (laplacernd (1, 1)), "double")
