@@ -1,4 +1,5 @@
 ## Copyright (C) 2024 Andreas Bertsatos <abertsatos@biol.uoa.gr>
+## Copyright (C) 2025 Swayam Shah <swayamshah66@gmail.com>
 ##
 ## This file is part of the statistics package for GNU Octave.
 ##
@@ -17,91 +18,219 @@
 
 classdef NakagamiDistribution
   ## -*- texinfo -*-
-  ## @deftypefn {statistics} NakagamiDistribution
+  ## @deftp {statistics} NakagamiDistribution
   ##
-  ## Normal probability distribution object.
+  ## Nakagami probability distribution object.
   ##
   ## A @code{NakagamiDistribution} object consists of parameters, a model
-  ## description, and sample data for a normal probability distribution.
+  ## description, and sample data for a Nakagami probability distribution.
   ##
-  ## The normal distribution uses the following parameters.
-  ##
-  ## @multitable @columnfractions 0.25 0.48 0.27
-  ## @headitem @var{Parameter} @tab @var{Description} @tab @var{Support}
-  ##
-  ## @item @qcode{mu} @tab Number of successes @tab @math{mu > 0}
-  ## @item @qcode{omega} @tab Probability of success @tab @math{omega > 0}
-  ## @end multitable
+  ## The Nakagami distribution is a continuous probability distribution that
+  ## models the amplitude of received signals after maximum ratio diversity
+  ## combining.  It is defined by shape parameter @var{mu} and spread parameter
+  ## @var{omega}.
   ##
   ## There are several ways to create a @code{NakagamiDistribution} object.
   ##
   ## @itemize
   ## @item Fit a distribution to data using the @code{fitdist} function.
-  ## @item Create a distribution with specified parameter values using the
+  ## @item Create a distribution with fixed parameter values using the
   ## @code{makedist} function.
-  ## @item Use the constructor @qcode{NakagamiDistribution (@var{mu}, @var{omega})}
-  ## to create a normal distribution with specified parameter values.
+  ## @item Use the constructor @qcode{NakagamiDistribution (@var{mu},
+  ## @var{omega})} to create a Nakagami distribution with fixed parameter
+  ## values @var{mu} and @var{omega}.
   ## @item Use the static method @qcode{NakagamiDistribution.fit (@var{x},
-  ## @var{censor}, @var{freq}, @var{options})} to a distribution to data @var{x}.
+  ## @var{censor}, @var{freq}, @var{options})} to fit a distribution to the data
+  ## in @var{x} using the same input arguments as the @code{nakafit} function.
   ## @end itemize
   ##
   ## It is highly recommended to use @code{fitdist} and @code{makedist}
-  ## functions to create probability distribution objects, instead of the
-  ## constructor and the aforementioned static method.
-  ##
-  ## A @code{NakagamiDistribution} object contains the following properties,
-  ## which can be accessed using dot notation.
-  ##
-  ## @multitable @columnfractions 0.25 0.25 0.25 0.25
-  ## @item @qcode{DistributionName} @tab @qcode{DistributionCode} @tab
-  ## @qcode{NumParameters} @tab @qcode{ParameterNames}
-  ## @item @qcode{ParameterDescription} @tab @qcode{ParameterValues} @tab
-  ## @qcode{ParameterValues} @tab @qcode{ParameterCI}
-  ## @item @qcode{ParameterIsFixed} @tab @qcode{Truncation} @tab
-  ## @qcode{IsTruncated} @tab @qcode{InputData}
-  ## @end multitable
-  ##
-  ## A @code{NakagamiDistribution} object contains the following methods:
-  ## @code{cdf}, @code{icdf}, @code{iqr}, @code{mean}, @code{median},
-  ## @code{negloglik}, @code{paramci}, @code{pdf}, @code{plot}, @code{proflik},
-  ## @code{random}, @code{std}, @code{truncate}, @code{var}.
+  ## functions to create probability distribution objects, instead of the class
+  ## constructor or the aforementioned static method.
   ##
   ## Further information about the Nakagami distribution can be found at
   ## @url{https://en.wikipedia.org/wiki/Nakagami_distribution}
   ##
   ## @seealso{fitdist, makedist, nakacdf, nakainv, nakapdf, nakarnd, nakafit,
   ## nakalike, nakastat}
-  ## @end deftypefn
+  ## @end deftp
 
   properties (Dependent = true)
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} mu
+    ##
+    ## Shape parameter
+    ##
+    ## A positive scalar value characterizing the shape of the
+    ## Nakagami distribution.  You can access the @qcode{mu}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     mu
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} omega
+    ##
+    ## Spread parameter
+    ##
+    ## A positive scalar value characterizing the spread of the
+    ## Nakagami distribution.  You can access the @qcode{omega}
+    ## property using dot name assignment.
+    ##
+    ## @end deftp
     omega
   endproperties
 
   properties (GetAccess = public, Constant = true)
-    CensoringAllowed = true;
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} DistributionName
+    ##
+    ## Probability distribution name
+    ##
+    ## A character vector specifying the name of the probability distribution
+    ## object.  This property is read-only.
+    ##
+    ## @end deftp
     DistributionName = "NakagamiDistribution";
-    DistributionCode = "naka";
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} NumParameters
+    ##
+    ## Number of parameters
+    ##
+    ## A scalar integer value specifying the number of parameters characterizing
+    ## the probability distribution.  This property is read-only.
+    ##
+    ## @end deftp
     NumParameters = 2;
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} ParameterNames
+    ##
+    ## Names of parameters
+    ##
+    ## A @math{2x1} cell array of character vectors with each element containing
+    ## the name of a distribution parameter.  This property is read-only.
+    ##
+    ## @end deftp
     ParameterNames = {"mu", "omega"};
-    ParameterDescription = {"Shape parameter", "Spread parameter"};
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} ParameterDescription
+    ##
+    ## Description of parameters
+    ##
+    ## A @math{2x1} cell array of character vectors with each element containing
+    ## a short description of a distribution parameter.  This property is
+    ## read-only.
+    ##
+    ## @end deftp
+    ParameterDescription = {"Shape", "Spread"};
   endproperties
 
-  properties (GetAccess = public, Constant = true)
+  properties (GetAccess = public, Constant = true, Hidden)
+    CensoringAllowed = true;
+    DistributionCode = "naka";
     ParameterRange = [0.5, realmin; Inf, Inf];
     ParameterLogCI = [true, true];
   endproperties
 
   properties (GetAccess = public , SetAccess = protected)
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} ParameterValues
+    ##
+    ## Distribution parameter values
+    ##
+    ## A @math{2x1} numeric vector containing the values of the distribution
+    ## parameters.  This property is read-only. You can change the distribution
+    ## parameters by assigning new values to the @qcode{mu} and @qcode{omega}
+    ## properties.
+    ##
+    ## @end deftp
     ParameterValues
-    ParameterCI
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} ParameterCovariance
+    ##
+    ## Covariance matrix of the parameter estimates
+    ##
+    ## A @math{2x2} numeric matrix containing the variance-covariance of the
+    ## parameter estimates.  Diagonal elements contain the variance of each
+    ## estimated parameter, and non-diagonal elements contain the covariance
+    ## between the parameter estimates.  The covariance matrix is only
+    ## meaningful when the distribution was fitted to data.  If the distribution
+    ## object was created with fixed parameters, or a parameter of a fitted
+    ## distribution is modified, then all elements of the variance-covariance
+    ## are zero.  This property is read-only.
+    ##
+    ## @end deftp
     ParameterCovariance
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} ParameterIsFixed
+    ##
+    ## Flag for fixed parameters
+    ##
+    ## A @math{1x2} logical vector specifying which parameters are fixed and
+    ## which are estimated.  @qcode{true} values correspond to fixed parameters,
+    ## @qcode{false} values correspond to parameter estimates.  This property is
+    ## read-only.
+    ##
+    ## @end deftp
     ParameterIsFixed
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} Truncation
+    ##
+    ## Truncation interval
+    ##
+    ## A @math{1x2} numeric vector specifying the truncation interval for the
+    ## probability distribution.  First element contains the lower boundary,
+    ## second element contains the upper boundary.  This property is read-only.
+    ## You can only truncate a probability distribution with the
+    ## @qcode{truncate} method.
+    ##
+    ## @end deftp
     Truncation
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} IsTruncated
+    ##
+    ## Flag for truncated probability distribution
+    ##
+    ## A logical scalar value specifying whether a probability distribution is
+    ## truncated or not.  This property is read-only.
+    ##
+    ## @end deftp
     IsTruncated
+
+    ## -*- texinfo -*-
+    ## @deftp {NakagamiDistribution} {property} InputData
+    ##
+    ## Data used for fitting a probability distribution
+    ##
+    ## A scalar structure containing the following fields:
+    ## @itemize
+    ## @item @qcode{data}: a numeric vector containing the data used for
+    ## distribution fitting.
+    ## @item @qcode{cens}: a numeric vector of logical values indicating
+    ## censoring information corresponding to the elements of the data used for
+    ## distribution fitting.  If no censoring vector was used for distribution
+    ## fitting, then this field defaults to an empty array.
+    ## @item @qcode{freq}: a numeric vector of non-negative integer values
+    ## containing the frequency information corresponding to the elements of the
+    ## data used for distribution fitting.  If no frequency vector was used for
+    ## distribution fitting, then this field defaults to an empty array.
+    ## @end itemize
+    ##
+    ## @end deftp
     InputData
   endproperties
 
+  properties (GetAccess = public, SetAccess = protected, Hidden)
+    ParameterCI
+  endproperties
+
   methods (Hidden)
 
     function this = NakagamiDistribution (mu, omega)
@@ -119,11 +248,11 @@ classdef NakagamiDistribution
 
     function display (this)
       fprintf ("%s =\n", inputname(1));
-      __disp__ (this, "normal distribution");
+      __disp__ (this, "Nakagami distribution");
     endfunction
 
     function disp (this)
-      __disp__ (this, "normal distribution");
+      __disp__ (this, "Nakagami distribution");
     endfunction
 
     function this = set.mu (this, mu)
@@ -200,13 +329,13 @@ classdef NakagamiDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {NakagamiDistribution} {@var{p} =} icdf (@var{pd}, @var{p})
+    ## @deftypefn  {NakagamiDistribution} {@var{x} =} icdf (@var{pd}, @var{p})
     ##
     ## Compute the inverse cumulative distribution function (iCDF).
     ##
-    ## @code{@var{p} = icdf (@var{pd}, @var{x})} computes the quantile (the
+    ## @code{@var{x} = icdf (@var{pd}, @var{p})} computes the quantile (the
     ## inverse of the CDF) of the probability distribution object, @var{pd},
-    ## evaluated at the values in @var{x}.
+    ## evaluated at the values in @var{p}.
     ##
     ## @end deftypefn
     function x = icdf (this, p)
@@ -293,8 +422,8 @@ classdef NakagamiDistribution
     ##
     ## Compute the negative loglikelihood of a probability distribution.
     ##
-    ## @code{@var{m} = negloglik (@var{pd})} computes the negative loglikelihood
-    ## of the probability distribution object, @var{pd}.
+    ## @code{@var{nlogL} = negloglik (@var{pd})} computes the negative
+    ## loglikelihood of the probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
     function nlogL = negloglik (this)
@@ -319,8 +448,8 @@ classdef NakagamiDistribution
     ## boundaries of the 95% confidence interval for each parameter of the
     ## probability distribution object, @var{pd}.
     ##
-    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes the
-    ## confidence intervals with additional options specified specified by
+    ## @code{@var{ci} = paramci (@var{pd}, @var{Name}, @var{Value})} computes
+    ## the confidence intervals with additional options specified by
     ## @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
@@ -383,7 +512,7 @@ classdef NakagamiDistribution
     ##
     ## Plot a probability distribution object.
     ##
-    ## @code{plot (@var{pd}} plots a probability density function (PDF) of the
+    ## @code{plot (@var{pd})} plots a probability density function (PDF) of the
     ## probability distribution object @var{pd}.  If @var{pd} contains data,
     ## which have been fitted by @code{fitdist}, the PDF is superimposed over a
     ## histogram of the data.
@@ -392,7 +521,7 @@ classdef NakagamiDistribution
     ## options with the @qcode{Name-Value} pair arguments listed below.
     ##
     ## @multitable @columnfractions 0.18 0.02 0.8
-    ## @headitem @tab @var{Name} @tab @var{Value}
+    ## @headitem @var{Name} @tab @tab @var{Value}
     ##
     ## @item @qcode{"PlotType"} @tab @tab A character vector specifying the plot
     ## type.  @qcode{"pdf"} plots the probability density function (PDF).  When
@@ -456,9 +585,9 @@ classdef NakagamiDistribution
     ## @var{setparam}, @qcode{"Display"}, @qcode{"on"})} also plots the profile
     ## likelihood against the user-defined range of the selected parameter.
     ##
-    ## For the negative binomial distribution, @qcode{@var{pnum} = 1} selects
-    ## the parameter @qcode{mu} and @qcode{@var{pnum} = 2} selects the parameter
-    ## @var{omega}.
+    ## For the Nakagami distribution, @qcode{@var{pnum} = 1} selects
+    ## the parameter @qcode{mu} and @qcode{@var{pnum} = 2} selects the
+    ## parameter @qcode{omega}.
     ##
     ## When opted to display the profile likelihood plot, @code{proflik} also
     ## plots the baseline loglikelihood computed at the lower bound of the 95%
@@ -478,10 +607,10 @@ classdef NakagamiDistribution
     endfunction
 
     ## -*- texinfo -*-
-    ## @deftypefn  {NakagamiDistribution} {@var{y} =} random (@var{pd})
-    ## @deftypefnx {NakagamiDistribution} {@var{y} =} random (@var{pd}, @var{rows})
-    ## @deftypefnx {NakagamiDistribution} {@var{y} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
-    ## @deftypefnx {NakagamiDistribution} {@var{y} =} random (@var{pd}, [@var{sz}])
+    ## @deftypefn  {NakagamiDistribution} {@var{r} =} random (@var{pd})
+    ## @deftypefnx {NakagamiDistribution} {@var{r} =} random (@var{pd}, @var{rows})
+    ## @deftypefnx {NakagamiDistribution} {@var{r} =} random (@var{pd}, @var{rows}, @var{cols}, @dots{})
+    ## @deftypefnx {NakagamiDistribution} {@var{r} =} random (@var{pd}, [@var{sz}])
     ##
     ## Generate random arrays from the probability distribution object.
     ##
@@ -542,13 +671,14 @@ classdef NakagamiDistribution
     ##
     ## Truncate a probability distribution.
     ##
-    ## @code{@var{t} = truncate (@var{pd})} returns a probability distribution
-    ## @var{t}, which is the probability distribution @var{pd} truncated to the
-    ## specified interval with lower limit, @var{lower}, and upper limit,
-    ## @var{upper}.  If @var{pd} is fitted to data with @code{fitdist}, the
-    ## returned probability distribution @var{t} is not fitted, does not contain
-    ## any data or estimated values, and it is as it has been created with the
-    ## @var{makedist} function, but it includes the truncation interval.
+    ## @code{@var{t} = truncate (@var{pd}, @var{lower}, @var{upper})} returns a
+    ## probability distribution @var{t}, which is the probability distribution
+    ## @var{pd} truncated to the specified interval with lower limit,
+    ## @var{lower}, and upper limit, @var{upper}.  If @var{pd} is fitted to data
+    ## with @code{fitdist}, the returned probability distribution @var{t} is not
+    ## fitted, does not contain any data or estimated values, and it is as it
+    ## has been created with the @var{makedist} function, but it includes the
+    ## truncation interval.
     ##
     ## @end deftypefn
     function this = truncate (this, lower, upper)
@@ -577,7 +707,7 @@ classdef NakagamiDistribution
     ##
     ## Compute the variance of a probability distribution.
     ##
-    ## @code{@var{v} = var (@var{pd})} computes the standard deviation of the
+    ## @code{@var{v} = var (@var{pd})} computes the variance of the
     ## probability distribution object, @var{pd}.
     ##
     ## @end deftypefn
@@ -656,6 +786,19 @@ function checkparams (mu, omega)
   endif
 endfunction
 
+%!demo
+%! ## Generate a data set of 5000 random samples from a Nakagami distribution with
+%! ## parameters mu = 1 and omega = 1.  Fit a Nakagami distribution to this data and plot
+%! ## a PDF of the fitted distribution superimposed on a histogram of the data.
+%!
+%! pd_fixed = makedist ("Nakagami", "mu", 1, "omega", 1)
+%! rand ("seed", 2);
+%! data = random (pd_fixed, 5000, 1);
+%! pd_fitted = fitdist (data, "Nakagami")
+%! plot (pd_fitted)
+%! msg = "Fitted Nakagami distribution with mu = %0.2f and omega = %0.2f";
+%! title (sprintf (msg, pd_fitted.mu, pd_fitted.omega))
+
 ## Test output
 %!shared pd, t
 %! pd = NakagamiDistribution;
