@@ -40,7 +40,11 @@
 ##
 ## @multitable @columnfractions 0.23 0.02 0.65
 ## @item @qcode{"euclidean"} @tab @tab Euclidean distance.
+## @item @qcode{"fasteuclidean"} @tab @tab Euclidean distance computed with an
+## alternative algorithm which may be faster but might reduce accuracy.
 ## @item @qcode{"squaredeuclidean"} @tab @tab Squared Euclidean distance.
+## @item @qcode{"fastsquaredeuclidean"} @tab @tab Euclidean distance computed
+## with an alternative algorithm which may be faster but might reduce accuracy.
 ## @item @qcode{"seuclidean"} @tab @tab standardized Euclidean distance.  Each
 ## coordinate difference between the rows in @var{X} and the query matrix
 ## @var{Y} is scaled by dividing by the corresponding element of the standard
@@ -99,7 +103,7 @@
 ## returns the matrix @var{I}, which contains the indices of the observations in
 ## @var{X} corresponding to the distances in @var{D}.  You must specify either
 ## @qcode{"Smallest"} or @qcode{"Largest"} as an optional @var{Name}-@var{Value}
-## pair pair argument to compute the second output argument.
+## pair argument to compute the second output argument.
 ##
 ## @seealso{pdist, knnsearch, rangesearch}
 ## @end deftypefn
@@ -118,14 +122,15 @@ function [D, I] = pdist2 (X, Y, varargin)
   endif
 
   ## Add default values
-  Distance = "euclidean";   # Distance metric
+  Distance = 'euclidean';   # Distance metric
   DistParameter = [];       # Distance parameter
   SortOrder = [];           # Flag for sorting distances to find
 
   ## Parse additional Distance metric and Distance parameter (if available)
-  DMs = {"euclidean", "squaredeuclidean", "seuclidean", ...
-         "mahalanobis", "cityblock", "minkowski", "chebychev", ...
-         "cosine", "correlation", "hamming", "jaccard", "spearman"};
+  DMs = {'euclidean', 'squaredeuclidean', 'seuclidean', ...
+         'fasteuclidean', 'fastsquaredeuclidean', ...
+         'chebychev', 'cityblock', 'cosine', 'correlation', ...
+         'mahalanobis', 'minkowski', 'hamming', 'jaccard', 'spearman'};
   if (numel (varargin) > 0)
     if (any (strcmpi (DMs, varargin{1})))
       Distance = tolower (varargin{1});
@@ -155,12 +160,12 @@ function [D, I] = pdist2 (X, Y, varargin)
       error ("pdist2: missing value in optional name/value paired arguments.");
     endif
     switch (tolower (varargin{1}))
-      case "smallest"
-        SortOrder = "ascend";
+      case 'smallest'
+        SortOrder = 'ascend';
         K = varargin{2};
         parcount += 1;
-      case "largest"
-        SortOrder = "descend";
+      case 'largest'
+        SortOrder = 'descend';
         K = varargin{2};
         parcount += 1;
       otherwise
@@ -170,126 +175,53 @@ function [D, I] = pdist2 (X, Y, varargin)
   endwhile
 
   ## Check additional arguments
+  if (parcount > 0)
+    if (fix (K) != K || K < 1)
+      error ("pdist2: K must be a positive integer value.");
+    endif
+  endif
   if (parcount > 1)
-    error ("pdist2: you can only use either Smallest or Largest.");
+    error ("pdist2: you can only specify either 'Smallest' or 'Largest'.");
   endif
   if (isempty (SortOrder) && nargout > 1)
-    error (strcat (["pdist2: Smallest or Largest must be specified"], ...
-                   [" to compute second output."]));
+    error (strcat ("pdist2: 'Smallest' or 'Largest' must be", ...
+                   " specified to compute second output."));
   endif
 
-  ## Calculate selected distance
-  [ix, iy] = meshgrid (1:size (X, 1), 1:size (Y, 1));
+  ## FAST PATH: Optimization for fast Euclidean algorithm
+  fast_algs = {'fasteuclidean', 'fastsquaredeuclidean'};
+  if (ischar (Distance) && ismember (Distance, fast_algs))
 
-  ## Handle build-in distance metric
-  if (ischar (Distance))
-    switch (Distance)
-      case "euclidean"
-        D = sqrt (sum ((X(ix(:),:) - Y(iy(:),:)) .^ 2, 2));
+    ## sumsq avoids the temporary memory of X.^2
+    ## D = ||x||^2 + ||y||^2 - 2x.y
+    D = sumsq (X, 2) + sumsq (Y, 2).' - 2 * (X * Y');
 
-      case "squaredeuclidean"
-        D = sum ((X(ix(:),:) - Y(iy(:),:)) .^ 2, 2);
+    ## Remove possible numerical negative noise
+    D = max (D, 0);
 
-      case "seuclidean"
-        if (isempty (DistParameter))
-          DistParameter = std (X, [], 1);
-        else
-          if (numel (DistParameter) != columns (X))
-            error (strcat (["pdist2: DistParameter for standardized"], ...
-                           [" euclidean must be a vector of equal length"], ...
-                           [" to the number of columns in X."]));
-          endif
-          if (any (DistParameter < 0))
-            error (strcat (["pdist2: DistParameter for standardized"], ...
-                           [" euclidean must be a nonnegative vector."]));
-          endif
-        endif
-        DistParameter(DistParameter == 0) = 1;  # fix constant variable
-        D = sqrt (sum (((X(ix(:),:) - Y(iy(:),:)) ./ DistParameter) .^ 2, 2));
+    if (strcmp (Distance, 'fasteuclidean'))
+      D = sqrt (D);
+    endif
 
-      case "mahalanobis"
-        if (isempty (DistParameter))
-          DistParameter = cov (X(! any (isnan (X), 2),:));
-        else
-          if (columns (DistParameter) != columns (X))
-            error (strcat (["pdist2: DistParameter for mahalanobis"], ...
-                           [" distance must be a covariance matrix with"], ...
-                           [" the same number of columns as X."]));
-          endif
-          [~, p] = chol (DistParameter);
-          if (p != 0)
-            error (strcat (["pdist2: covariance matrix for mahalanobis"], ...
-                           [" distance must be symmetric and positive"], ...
-                           [" definite."]));
-          endif
-        endif
-        ## Catch warning if matrix is close to singular or badly scaled.
-        [DP_inv, rc] = inv (DistParameter);
-        if (rc < eps)
-          msg = sprintf (strcat (["pdist2: matrix is close to"], ...
-                                 [" singular or badly scaled.\n RCOND = "], ...
-                                 [" %e. Results may be inaccurate."]), rc);
-          warning (msg);
-        endif
-        dxy = X(ix(:),:) - Y(iy(:),:);
-        D   = sqrt (sum ((dxy * DP_inv) .* dxy, 2));
+    ## Handle SortOrder (Smallest/Largest) output if requested
+    if (nargout > 1 || parcount)
+      ## This finds K nearest X's for each Y.
+      [D, I] = sort (D, 1, SortOrder);
 
-      case "cityblock"
-        D = sum (abs (X(ix(:),:) - Y(iy(:),:)), 2);
+      K = min (size (D, 1), K);
+      D = D(1:K, :);
+      I = I(1:K, :);
+    endif
 
-      case "minkowski"
-        if (isempty (DistParameter))
-          DistParameter = 2;
-        else
-          if (! (isnumeric (DistParameter) && isscalar (DistParameter)
-                                           && DistParameter > 0))
-            error (strcat (["pdist2: DistParameter for minkowski distance"],...
-                           [" must be a positive scalar."]));
-          endif
-        endif
-        D = sum (abs (X(ix(:),:) - Y(iy(:),:)) .^ DistParameter, 2) .^ ...
-                (1 / DistParameter);
-
-      case "chebychev"
-        D = max (abs (X(ix(:),:) - Y(iy(:),:)), [], 2);
-
-      case "cosine"
-        sx = sum (X .^ 2, 2) .^ (-1 / 2);
-        sy = sum (Y .^ 2, 2) .^ (-1 / 2);
-        D  = 1 - sum (X(ix(:),:) .* Y(iy(:),:), 2) .* sx(ix(:)) .* sy(iy(:));
-
-      case "correlation"
-        mX = mean (X(ix(:),:), 2);
-        mY = mean (Y(iy(:),:), 2);
-        xy = sum ((X(ix(:),:) - mX) .* (Y(iy(:),:) - mY), 2);
-        xx = sqrt (sum ((X(ix(:),:) - mX) .* (X(ix(:),:) - mX), 2));
-        yy = sqrt (sum ((Y(iy(:),:) - mY) .* (Y(iy(:),:) - mY), 2));
-        D = 1 - (xy ./ (xx .* yy));
-
-      case "hamming"
-        D = mean (abs (X(ix(:),:) != Y(iy(:),:)), 2);
-
-      case "jaccard"
-        xy0 = (X(ix(:),:) != 0 | Y(iy(:),:) != 0);
-        D = sum ((X(ix(:),:) != Y(iy(:),:)) & xy0, 2) ./ sum (xy0, 2);
-
-      case "spearman"
-        for i = 1:size (X, 1)
-          rX(i,:) = tiedrank (X(i,:));
-        endfor
-        for i = 1:size (Y, 1)
-          rY(i,:) = tiedrank (Y(i,:));
-        endfor
-        rM = (size (X, 2) + 1) / 2;
-        xy = sum ((rX(ix(:),:) - rM) .* (rY(iy(:),:) - rM), 2);
-        xx = sqrt (sum ((rX(ix(:),:) - rM) .* (rX(ix(:),:) - rM), 2));
-        yy = sqrt (sum ((rY(iy(:),:) - rM) .* (rY(iy(:),:) - rM), 2));
-        D = 1 - (xy ./ (xx .* yy));
-
-    endswitch
+    return;
   endif
 
-  ## Handle a function handle
+  ## Threshold for switching between vectorized and blocked computation
+  M = size (X, 1);
+  Nrows = size (Y, 1);
+  N_threshold = 500;
+
+  ## Handle a function handle (always row-by-row)
   if (is_function_handle (Distance))
     ## Check the input output sizes of the user function
     D2 = [];
@@ -298,23 +230,293 @@ function [D, I] = pdist2 (X, Y, varargin)
     catch ME
       error ("pdist2: invalid function handle for distance metric.");
     end_try_catch
-    Yrows = rows (Y);
-    if (! isequal (size (D2), [Yrows, 1]))
+    if (! isequal (size (D2), [Nrows, 1]))
       error ("pdist2: custom distance function produces wrong output size.");
     endif
     ## Evaluate user defined distance metric function
-    Yrows = rows (Y);
-    D = zeros (numel (ix), 1);
-    id_beg = 1;
-    for r = 1:rows (X)
-      id_end = id_beg + Yrows - 1;
-      D(id_beg:id_end) = feval (Distance, X(r,:), Y);
-      id_beg = id_end + 1;
+    D = zeros (M, Nrows);
+    for r = 1:M
+      D(r,:) = feval (Distance, X(r,:), Y)';
     endfor
+
+    if (nargout > 1 || parcount)
+      [D, I] = sort (D', 2, SortOrder);
+      K = min (size (D, 2), K);
+      D = D(:,1:K)';
+      I = I(:,1:K)';
+    endif
+    return;
   endif
 
-  ## From vector to matrix
-  D = reshape (D, size (Y, 1), size (X, 1))';
+  ## For small M and N: use original vectorized implementation (fast, O(M*N*P) memory)
+  ## For large M or N: use blocked row-by-row computation (slower, O(N*P) memory)
+  if (max (M, Nrows) < N_threshold)
+    ## Original vectorized implementation
+    if (strcmp (Distance, 'cosine'))
+      X_inv_norm = 1 ./ sqrt (sumsq (X, 2));
+      Y_inv_norm = 1 ./ sqrt (sumsq (Y, 2));
+
+      ## Normalize the matrices in-place (broadcasting)
+      X = X .* X_inv_norm;
+      Y = Y .* Y_inv_norm;
+
+      ## Cosine distance = 1 - dot_product (normalized vectors)
+      D = 1 - (X * Y');
+
+    else
+      ## Create indexing grid
+      [ix, iy] = meshgrid (1:M, 1:Nrows);
+
+      switch (Distance)
+        case 'euclidean'
+          D = sqrt (sum ((X(ix(:),:) - Y(iy(:),:)) .^ 2, 2));
+
+        case 'squaredeuclidean'
+          D = sum ((X(ix(:),:) - Y(iy(:),:)) .^ 2, 2);
+
+        case 'seuclidean'
+          if (isempty (DistParameter))
+            DistParameter = std (X, [], 1);
+          else
+            if (numel (DistParameter) != columns (X))
+              error (strcat ("pdist2: DistParameter for standardized", ...
+                             " euclidean must be a vector of equal length", ...
+                             " to the number of columns in X."));
+            endif
+            if (any (DistParameter < 0))
+              error (strcat ("pdist2: DistParameter for standardized", ...
+                             " euclidean must be a nonnegative vector."));
+            endif
+          endif
+          DistParameter(DistParameter == 0) = 1;  # fix constant variable
+          D = sqrt (sum (((X(ix(:),:) - Y(iy(:),:)) ./ DistParameter) .^ 2, 2));
+
+        case 'mahalanobis'
+          if (isempty (DistParameter))
+            DistParameter = cov (X(! any (isnan (X), 2),:));
+          else
+            if (columns (DistParameter) != columns (X))
+              error (strcat ("pdist2: DistParameter for mahalanobis", ...
+                             " distance must be a covariance matrix with", ...
+                             " the same number of columns as X."));
+            endif
+            [~, p] = chol (DistParameter);
+            if (p != 0)
+              error (strcat ("pdist2: covariance matrix for mahalanobis", ...
+                             " distance must be symmetric and positive", ...
+                             " definite."));
+            endif
+          endif
+          ## Catch warning if matrix is close to singular or badly scaled.
+          [DP_inv, rc] = inv (DistParameter);
+          if (rc < eps)
+            msg = sprintf (strcat ("pdist2: matrix is close to", ...
+                                   " singular or badly scaled.\n RCOND = ", ...
+                                   " %e. Results may be inaccurate."), rc);
+            warning (msg);
+          endif
+          dxy = X(ix(:),:) - Y(iy(:),:);
+          D = sqrt (sum ((dxy * DP_inv) .* dxy, 2));
+
+        case 'cityblock'
+          D = sum (abs (X(ix(:),:) - Y(iy(:),:)), 2);
+
+        case 'minkowski'
+          if (isempty (DistParameter))
+            DistParameter = 2;
+          else
+            if (! (isnumeric (DistParameter) && isscalar (DistParameter)
+                                             && DistParameter > 0))
+              error (strcat ("pdist2: DistParameter for minkowski distance", ...
+                             " must be a positive scalar."));
+            endif
+          endif
+          D = sum (abs (X(ix(:),:) - Y(iy(:),:)) .^ DistParameter, 2) .^ ...
+                  (1 / DistParameter);
+
+        case 'chebychev'
+          D = max (abs (X(ix(:),:) - Y(iy(:),:)), [], 2);
+
+        case 'correlation'
+          mX = mean (X(ix(:),:), 2);
+          mY = mean (Y(iy(:),:), 2);
+          xy = sum ((X(ix(:),:) - mX) .* (Y(iy(:),:) - mY), 2);
+          xx = sqrt (sum ((X(ix(:),:) - mX) .* (X(ix(:),:) - mX), 2));
+          yy = sqrt (sum ((Y(iy(:),:) - mY) .* (Y(iy(:),:) - mY), 2));
+          D = 1 - (xy ./ (xx .* yy));
+
+        case 'hamming'
+          D = mean (abs (X(ix(:),:) != Y(iy(:),:)), 2);
+
+        case 'jaccard'
+          xy0 = (X(ix(:),:) != 0 | Y(iy(:),:) != 0);
+          D = sum ((X(ix(:),:) != Y(iy(:),:)) & xy0, 2) ./ sum (xy0, 2);
+
+        case 'spearman'
+          for i = 1:M
+            rX(i,:) = tiedrank (X(i,:));
+          endfor
+          for i = 1:Nrows
+            rY(i,:) = tiedrank (Y(i,:));
+          endfor
+          rM = (size (X, 2) + 1) / 2;
+          xy = sum ((rX(ix(:),:) - rM) .* (rY(iy(:),:) - rM), 2);
+          xx = sqrt (sum ((rX(ix(:),:) - rM) .* (rX(ix(:),:) - rM), 2));
+          yy = sqrt (sum ((rY(iy(:),:) - rM) .* (rY(iy(:),:) - rM), 2));
+          D = 1 - (xy ./ (xx .* yy));
+      endswitch
+
+      ## From vector to matrix
+      D = reshape (D, Nrows, M)';
+
+    endif
+
+  else
+    ## Blocked row-by-row computation for large M or N (avoids O(M*N*P) memory)
+    D = zeros (M, Nrows);
+
+    ## Precompute metric-specific data
+    switch (Distance)
+      case 'seuclidean'
+        if (isempty (DistParameter))
+          DistParameter = std (X, [], 1);
+        else
+          if (numel (DistParameter) != columns (X))
+            error (strcat ("pdist2: DistParameter for standardized", ...
+                           " euclidean must be a vector of equal length", ...
+                           " to the number of columns in X."));
+          endif
+          if (any (DistParameter < 0))
+            error (strcat ("pdist2: DistParameter for standardized", ...
+                           " euclidean must be a nonnegative vector."));
+          endif
+        endif
+        DistParameter(DistParameter == 0) = 1;
+
+      case 'mahalanobis'
+        if (isempty (DistParameter))
+          DistParameter = cov (X(! any (isnan (X), 2),:));
+        else
+          if (columns (DistParameter) != columns (X))
+            error (strcat ("pdist2: DistParameter for mahalanobis", ...
+                           " distance must be a covariance matrix with", ...
+                           " the same number of columns as X."));
+          endif
+          [~, p] = chol (DistParameter);
+          if (p != 0)
+            error (strcat ("pdist2: covariance matrix for mahalanobis", ...
+                           " distance must be symmetric and positive", ...
+                           " definite."));
+          endif
+        endif
+        [DP_inv, rc] = inv (DistParameter);
+        if (rc < eps)
+          msg = sprintf (strcat ("pdist2: matrix is close to", ...
+                                 " singular or badly scaled.\n RCOND = ", ...
+                                 " %e. Results may be inaccurate."), rc);
+          warning (msg);
+        endif
+
+      case 'minkowski'
+        if (isempty (DistParameter))
+          DistParameter = 2;
+        else
+          if (! (isnumeric (DistParameter) && isscalar (DistParameter)
+                                           && DistParameter > 0))
+            error (strcat ("pdist2: DistParameter for minkowski distance", ...
+                           " must be a positive scalar."));
+          endif
+        endif
+
+      case 'cosine'
+        sx = sum (X .^ 2, 2) .^ (-1 / 2);
+        sy = sum (Y .^ 2, 2) .^ (-1 / 2);
+
+      case 'spearman'
+        rX = zeros (size (X));
+        rY = zeros (size (Y));
+        for i = 1:M
+          rX(i,:) = tiedrank (X(i,:));
+        endfor
+        for i = 1:Nrows
+          rY(i,:) = tiedrank (Y(i,:));
+        endfor
+        rM = (size (X, 2) + 1) / 2;
+    endswitch
+
+    ## Row-by-row computation with switch outside loop
+    switch (Distance)
+      case 'euclidean'
+        for i = 1:M
+          D(i,:) = sqrt (sum ((X(i,:) - Y) .^ 2, 2))';
+        endfor
+
+      case 'squaredeuclidean'
+        for i = 1:M
+          D(i,:) = sum ((X(i,:) - Y) .^ 2, 2)';
+        endfor
+
+      case 'seuclidean'
+        for i = 1:M
+          D(i,:) = sqrt (sum (((X(i,:) - Y) ./ DistParameter) .^ 2, 2))';
+        endfor
+
+      case 'mahalanobis'
+        for i = 1:M
+          dxy = X(i,:) - Y;
+          D(i,:) = sqrt (sum ((dxy * DP_inv) .* dxy, 2))';
+        endfor
+
+      case 'cityblock'
+        for i = 1:M
+          D(i,:) = sum (abs (X(i,:) - Y), 2)';
+        endfor
+
+      case 'minkowski'
+        for i = 1:M
+          D(i,:) = (sum (abs (X(i,:) - Y) .^ DistParameter, 2) .^ (1 / DistParameter))';
+        endfor
+
+      case 'chebychev'
+        for i = 1:M
+          D(i,:) = max (abs (X(i,:) - Y), [], 2)';
+        endfor
+
+      case 'cosine'
+        for i = 1:M
+          D(i,:) = (1 - sum (X(i,:) .* Y, 2) .* sx(i) .* sy)';
+        endfor
+
+      case 'correlation'
+        for i = 1:M
+          mXi = mean (X(i,:));
+          mY = mean (Y, 2);
+          xy = sum ((X(i,:) - mXi) .* (Y - mY), 2);
+          xx = sqrt (sum ((X(i,:) - mXi) .^ 2));
+          yy = sqrt (sum ((Y - mY) .^ 2, 2));
+          D(i,:) = (1 - (xy ./ (xx .* yy)))';
+        endfor
+
+      case 'hamming'
+        for i = 1:M
+          D(i,:) = mean (abs (X(i,:) != Y), 2)';
+        endfor
+
+      case 'jaccard'
+        for i = 1:M
+          xy0 = (X(i,:) != 0 | Y != 0);
+          D(i,:) = (sum ((X(i,:) != Y) & xy0, 2) ./ sum (xy0, 2))';
+        endfor
+
+      case 'spearman'
+        for i = 1:M
+          xy = sum ((rX(i,:) - rM) .* (rY - rM), 2);
+          xx = sqrt (sum ((rX(i,:) - rM) .^ 2));
+          yy = sqrt (sum ((rY - rM) .^ 2, 2));
+          D(i,:) = (1 - (xy ./ (xx .* yy)))';
+        endfor
+    endswitch
+  endif
 
   if (nargout > 1 || parcount)
     [D, I] = sort (D', 2, SortOrder);
@@ -427,9 +629,11 @@ endfunction
 %! pdist2 (ones (3), ones (3), "minkowski", 3, "Largest")
 %!error<pdist2: invalid NAME in optional pairs of arguments.> ...
 %! pdist2 (ones (3), ones (3), "minkowski", 3, "large", 4)
-%!error<pdist2: you can only use either Smallest or Largest.> ...
+%!error<pdist2: K must be a positive integer value.> ...
+%! pdist2 (ones (3), ones (3), "minkowski", 3, "largest", 4.5)
+%!error<pdist2: you can only specify either 'Smallest' or 'Largest'.> ...
 %! pdist2 (ones (3), ones (3), "minkowski", 3, "Largest", 4, "smallest", 5)
-%!error<pdist2: Smallest or Largest must be specified to compute second output.> ...
+%!error<pdist2: 'Smallest' or 'Largest' must be specified to compute second output.> ...
 %! [d, i] = pdist2(ones (3), ones (3), "minkowski", 3)
 %!error<pdist2: DistParameter for standardized euclidean must be a vector of> ...
 %! pdist2 (ones (3), ones (3), "seuclidean", 3)
